# Asteroid Odyssey

The official Python SDK for interacting with the Asteroid Agents API.

## Installation

```bash
pip install asteroid-odyssey
```

## Usage

Please head to our documentation at https://docs.asteroid.ai/sdk/python

## License

The Asteroid Odyssey SDK is available under the MIT License.
